==> apache-tinkerpop-3.4.0-src.zip: tinkerpop-3.4.0/gremlin-driver/src/main/java/org/apache/tinkerpop/gremlin/driver/ser/binary/types/BigIntegerSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.driver.ser.binary.types;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufAllocator;
import org.apache.tinkerpop.gremlin.driver.ser.SerializationException;
import org.apache.tinkerpop.gremlin.driver.ser.binary.DataType;
import org.apache.tinkerpop.gremlin.driver.ser.binary.GraphBinaryReader;
import org.apache.tinkerpop.gremlin.driver.ser.binary.GraphBinaryWriter;

import java.math.BigInteger;

/**
 * @author Stephen Mallette (http://stephen.genoprime.com)
 */
public class BigIntegerSerializer extends SimpleTypeSerializer<BigInteger> {

    public BigIntegerSerializer(){
        super(DataType.BIGINTEGER);
    }

    @Override
    BigInteger readValue(final ByteBuf buffer, final GraphBinaryReader context) throws SerializationException {
        final byte[] bigIntBytes = new byte[buffer.readInt()];
        buffer.readBytes(bigIntBytes);
        return new BigInteger(bigIntBytes);
    }

    @Override
    public ByteBuf writeValue(final BigInteger value, final ByteBufAllocator allocator, final GraphBinaryWriter context) throws SerializationException {
        final byte[] twosComplement = value.toByteArray();
        return allocator.buffer(4 + twosComplement.length).writeInt(twosComplement.length).writeBytes(twosComplement);
    }
}

==> apache-tinkerpop-3.4.1-src.zip: tinkerpop-3.4.1/gremlin-driver/src/main/java/org/apache/tinkerpop/gremlin/driver/ser/binary/types/BigIntegerSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.driver.ser.binary.types;

import io.netty.buffer.ByteBuf;
import org.apache.tinkerpop.gremlin.driver.ser.SerializationException;
import org.apache.tinkerpop.gremlin.driver.ser.binary.DataType;
import org.apache.tinkerpop.gremlin.driver.ser.binary.GraphBinaryReader;
import org.apache.tinkerpop.gremlin.driver.ser.binary.GraphBinaryWriter;

import java.math.BigInteger;

/**
 * @author Stephen Mallette (http://stephen.genoprime.com)
 */
public class BigIntegerSerializer extends SimpleTypeSerializer<BigInteger> {

    public BigIntegerSerializer(){
        super(DataType.BIGINTEGER);
    }

    @Override
    protected BigInteger readValue(final ByteBuf buffer, final GraphBinaryReader context) throws SerializationException {
        final byte[] bigIntBytes = new byte[buffer.readInt()];
        buffer.readBytes(bigIntBytes);
        return new BigInteger(bigIntBytes);
    }

    @Override
    protected void writeValue(final BigInteger value, final ByteBuf buffer, final GraphBinaryWriter context) throws SerializationException {
        final byte[] twosComplement = value.toByteArray();
        buffer.writeInt(twosComplement.length).writeBytes(twosComplement);
    }
}
